package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.CharacterMarkerSymbol;
import com.esri.arcgis.support.ms.stdole.Font;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;


import org.w3c.dom.Element;
import java.awt.Color;

/**
 * Reads character marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class CharacterMarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(CharacterMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private CharacterMarkerSymbol symbol;

    public CharacterMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof CharacterMarkerSymbol) {
            this.symbol = (CharacterMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a CharacterMarkerSymbol!");
        }
    }

    public CharacterMarkerSymbolReader(IMarkerSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof CharacterMarkerSymbol) {
            this.symbol = (CharacterMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a CharacterMarkerSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        symbolElement.setAttribute(
            "angle",
            String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute(
            "size",
            String.valueOf(symbol.getSize()));
        symbolElement.setAttribute(
            "x_offset",
            String.valueOf(symbol.getXOffset()));
        symbolElement.setAttribute(
            "y_offset",
            String.valueOf(symbol.getYOffset()));
        symbolElement.setAttribute(
            "name",
            symbol.getNameString());
        symbolElement.setAttribute(
            "char",
            String.valueOf(symbol.getCharacterIndex()));

        if(symbol.getColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getColor();
            Color c = new Color (
                color.getRed(),
                color.getGreen(),
                color.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
            symbolElement.setAttribute("transparency",
                String.valueOf(color.getTransparency()));
        }
        else {
            RgbColor col = new RgbColor();
            col.setRGB(symbol.getColor().getRGB());
            Color c = new Color (
                col.getRed(),
                col.getGreen(),
                col.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
            symbolElement.setAttribute("transparency",
                String.valueOf(col.getTransparency()));
        }

        Font f = symbol.getFont();
        symbolElement.setAttribute("font", f.getName());
        symbolElement.setAttribute("char_set", String.valueOf(f.getCharset()));
        symbolElement.setAttribute("bold", String.valueOf(f.getBold()));
        symbolElement.setAttribute("italic", String.valueOf(f.getItalic()));
        symbolElement.setAttribute("font_size", String.valueOf(f.getSize()));
        symbolElement.setAttribute(
            "strike_through",
            String.valueOf(f.getStrikethrough()));
        symbolElement.setAttribute("weight", String.valueOf(f.getWeight()));
        symbolElement.setAttribute("style", "char");
        symbolElement.setAttribute("type", "marker");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
